/*
 * Copyright 2013-2014 aquenos GmbH.
 * All rights reserved.
 * 
 * This program and the accompanying materials are made available under the 
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 */

package com.aquenos.csstudio.archive.json.reader.internal;

import java.util.List;

import org.epics.util.array.ArrayInt;
import org.epics.util.array.ListDouble;
import org.epics.util.array.ListInt;
import org.epics.util.time.Timestamp;
import org.epics.vtype.AlarmSeverity;
import org.epics.vtype.ArrayDimensionDisplay;
import org.epics.vtype.Display;
import org.epics.vtype.VDoubleArray;
import org.epics.vtype.ValueUtil;

/**
 * Averaged sample with multiple double elements.
 * 
 * @author Sebastian Marsching
 */
public class DoubleArrayStatistics extends AbstractStatistics implements
        VDoubleArray {

    private ListDouble data;

    public DoubleArrayStatistics(ListDouble data, String alarmName,
            AlarmSeverity alarmSeverity, Display display, Double min,
            Double max, Integer nSamples, Double stdDev, Integer timeUserTag,
            Timestamp timestamp, boolean timeValid) {
        super(alarmName, alarmSeverity, display, min, max, nSamples, stdDev,
                timeUserTag, timestamp, timeValid);
        this.data = data;
    }

    @Override
    public Double getAverage() {
        // We return the first element of the array (this is the average of the
        // first elements of all arrays).
        if (data == null) {
            return null;
        }
        return data.size() > 0 ? data.getDouble(0) : null;
    }

    @Override
    public List<ArrayDimensionDisplay> getDimensionDisplay() {
        return ValueUtil.defaultArrayDisplay(this);
    }

    @Override
    public ListInt getSizes() {
        return new ArrayInt(data != null ? data.size() : 0);
    }

    @Override
    public ListDouble getData() {
        return data;
    }

}
